# Welcome to CSZP Easy Soccer Execution Program!

この度はCSZP Easy Soccer Execution Program（以下cszp）を使用していただき有難うございます。
確認しましたところ、使用が初めてだと思われるので、簡単な操作説明をさせていただきます。

使用するのが初めてではない方はqキーを押すと、メニュー画面に行きます。

また、この文章をもう一度読みたい場合はhelpコマンドで確認することが可能です。

そして、ブラウザでこの文章が読みたい場合は以下のURLにアクセスしてください。

[こちら](https://github.com/kumitatepazuru/cszp/wiki)

## 操作方法について

cszpは対話型の操作を取り入れています。なので、普通の端末のように
 * コマンドを入力
 * 実行
 * 結果が返ってくる
という形式で実行されていきます（細かく言うと少し違いますが）
また、入力を楽にする&見やすくするために一部では矢印キーとTabキーそしてマウスクリックも使用することができます。

## コマンドについて
今の所、プラグインを除けばコマンド入力はメニュー画面・設定画面でやります。形式は以下のとおりです。
```
cszp 簡単サッカー実行プログラム

start      試合をする
test       テスト試合をする
setting    設定をする
reset      リセットをかける
loop       試合を複数回する
lang       Change language/言語を変更
server     過去のloopログをサーバーで確認
plugin     プラグインの追加・確認をする
about      cszpの情報を表示する
exit       終了する   
>>>
```
左がコマンド、右が簡単な説明です。
下にある`>>>`にコマンドが入力されます。

## ヘルプについて

メニュー画面（起動したときの一番最初の画面）でhelpコマンドを実行、読みたい文章を上下キーで選択、Enterキーで実行すると確認できます。

## ライセンスについて
ライセンスはGNU 一般公衆利用許諾書v3を使用しています。詳しくは以下のページをご覧ください。

[英語版](https://github.com/kumitatepazuru/cszp/blob/master/LICENSE)

[日本語版](https://github.com/kumitatepazuru/cszp/blob/master/LICENSE_jp)
## 翻訳について
翻訳についてはDeepl 翻訳、みらい翻訳、Google 翻訳を使用しています。機械翻訳を使用しているのでおかしい部分があるかもしれません。もし、改善できる部分がありましたら、cszpのissueやpull requestで教えてください。よろしくおねがいします。

## 謝辞

このプログラムを考えてくれた自分の頭、このプログラムを作成するのを手伝ってくれたjyo_senチームの皆さん本当に有難うございます。
この場を借りてお礼申し上げます。